@@ -1,3 +1,14 @@
+#
+# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/manifest.tcl,v $
+# $Date: 1998/04/20 11:42:31 $
+# $Revision: 1.18.1.175 $
+#
+# ----------------------------------------------------------------------
+#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
+# ----------------------------------------------------------------------
+# Copyright 1997 The University of Newcastle upon Tyne (see COPYRIGHT)
+# ======================================================================
+#
 array set Manifest [list  \
     README					{} \
     [file join doc README.ONS]			{} \
@@ -93,6 +104,7 @@ array set Manifest [list  \
     [file join lib Net.tcl]			{copy} \
     [file join lib Notice.tcl]			{copy} \
     [file join lib On.tcl]			{copy} \
+    [file join lib Protect.tcl]			{copy} \
     [file join lib Server.tcl]			{copy} \
     [file join lib Service.tcl]			{copy} \
     [file join lib Sound.tcl]			{copy} \
@@ -229,5 +241,5 @@ array set Manifest [list  \
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 110
+set Patchlevel 119
 
