@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/03/23 12:49:49 $
-# $Revision: 1.18.1.141 $
+# $Date: 1998/04/20 11:42:09 $
+# $Revision: 1.18.1.145 $
 #
 #
 package provide zircon 1.18
@@ -49,7 +49,7 @@ proc oneLiner {win chid} {
     set x [split [$win get]]
     if {![string match {} [set who [lindex $x 0]]] &&
       ![string match {} [set msg [join [lrange $x 1 end]]]]} {
-	$net msg $who $msg
+	$net qSend PRIVMSG $who :$msg
 	$chid addText {} ">>$who : $msg"
     }
     $win delete 0 end
@@ -221,7 +221,7 @@ proc channel_setTopic {this string} {
 proc channel_changeMode {this mode} {
     upvar #0 $this cdata
     set val $cdata($mode)
-    set cdata($mode) [expr {!$val}]
+#    set cdata($mode) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]${mode}
 }
 #
@@ -333,9 +333,9 @@ proc channel_send {this string args} {
 	  {[info exists Secure($lc)] ? $Secure($lc) : [$this name]}]
 	set net [$this net]
 	switch {} [set key [$this crypt]] {
-	    $net msg $rchan $string
+	    $net qSend PRIVMSG $rchan :$string
 	} default {
-	    $net msg $rchan [encrypt $string $key]
+	    $net qSend PRIVMSG $rchan :[encrypt $string $key]
 	}
 	regsub -all %n [$this mytag] [[$net myid] name] pr
 	switch -- $args {} {
@@ -358,6 +358,11 @@ proc channel_isSpeaker {this usr} {
     return $cdata(Spk,$usr)
 }
 #
+proc channel_kickUser {this usr prefix kill} {
+    $usr protect $this $prefix [expr {$kill ? {#} : {!}}]
+    $this killUser $usr
+}
+#
 proc channel_killUser {this usr} {
     upvar #0 $this cdata
     set w $cdata(window)
@@ -732,7 +737,7 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     $om add separator
     foreach nn [$this topics] {
 	$om add command -label [prune $nn 15] \
-	  -command "$this configure -topic {$nn}"
+	  -command "$this configure -topic [list $nn]"
     }
     emacsTEntry $w.topic.entry
     bind $w.topic.entry <Escape> "notIdle %W $net ; $this makePalette Topic"
@@ -972,7 +977,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
 	$omm add separator
 	foreach x [$this messages] {
 	    $omm.menu add command -label [prune $x 15] \
-	      -command "$this send {$x}"
+	      -command "$this send [list $x]"
 	}
 	$om add command -command "\[$this dwin\] show" -label [trans draw]
 	if {![$this draw]} { $om entryconfigure 3 -state disabled }
@@ -1020,7 +1025,7 @@ proc makeCtlAction {this net w chan rchan idx look} {
     $om add separator
     foreach act [$net actions] {
 	$om add command -label [prune $act 15] \
-	  -command "$this action {$act}"
+	  -command "$this action [list $act]"
     }
 }
 #
@@ -1061,13 +1066,13 @@ proc makeCtlQuit {this net w chan rchan idx look} {
     $qm.menu add command -label [trans new] -command "getQuit $ctl"
     $qm.menu add separator
     foreach x [$net signoffs] { $qm.menu add command -label [prune $x 15] \
-	  -command "$net doQuit {$x}" }
+	  -command "$net doQuit [list $x]" }
     if {[$this isa Channel]} {	
 	$qm add separator
 	$qm add command -label [trans new] -command "getLeave $this"
 	$qm add separator
 	foreach x [$net leaves] {
-	    $qm add command -label [prune $x 15] -command "$this doLeave {$x}"
+	    $qm add command -label [prune $x 15] -command "$this doLeave [list $x]"
 	}
     }
     addImage $w.quit leave $w.cmds $idx $net
@@ -1145,7 +1150,7 @@ proc channel_keepMsg {this str} {
     switch {} $str {} default {
 	$this send $str
 	[$this window].channel.menu.msgs add command \
-	  -label "[prune $str 15]" -command "$this send {$str}"
+	  -label "[prune $str 15]" -command "$this send [list $str]"
 	[$this net] configure +messages $str +confChange Channels
     }
 }
@@ -1318,7 +1323,7 @@ proc channel_doAddText {this tag text} {
 proc channel_keepAction {this value} {
     $this action $value
     [$this window].action.menu add command -label "[prune $value 15]" \
-      -command "$this action {$value}"
+      -command "$this action [list $value]"
     [$this net] configure +actions $value +confChange Channels
 }
 #
@@ -1332,7 +1337,7 @@ proc channel_getAction {this} {
 #
 proc channel_action {this string} {
     switch {} $string {} default {
-	[$this net] msg [$this name] "\001ACTION $string\001"
+	[$this net] qSend PRIVMSG [$this name] ":\001ACTION $string\001"
 	$this addText @me "* [[$this net] nickname] $string"
 	$this addHist $string
     }
@@ -1596,7 +1601,7 @@ proc channel_userMode {this usr mode} {
     switch -exact -- $mode \
       o {set val [$this isOp $usr] ; set typ Op} \
       v {set val [$this isSpeaker $usr] ; set typ Spk}
-    set cdata($typ,$usr) [expr {!$val}]
+#    set cdata($typ,$usr) [expr {!$val}]
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]$mode [$usr name]
 }
 #
@@ -1611,7 +1616,7 @@ proc channel_setOps {this prefix usr} {
     }
 }
 #
-proc channel_mode {this vals} {
+proc channel_mode {this vals prefix} {
     upvar #0 $this cdata
     set net $cdata(net)
     set nxt {}
@@ -1685,11 +1690,13 @@ proc channel_mode {this vals} {
 	    switch -exact -- $m {
 	    o   {
 		    switch + $flag {set op markOp} default {set op unmarkOp}
-		    $this $op [User :: make $cdata(net) $par]
+		    $this $op [set who [User :: make $cdata(net) $par]]
+		    $who protect $this $prefix ${flag}o
 		}
 	    v   {
 		    switch + $flag {set op markV} default {set op unmarkV}
-		    $this $op [User :: make $cdata(net) $par]
+		    $this $op [set who [User :: make $cdata(net) $par]]
+		    $who protect $this $prefix ${flag}v
 		}
 	    k   {
 		    switch + $flag {set cdata(key) $par} default {set cdata(key) {}}
@@ -1699,6 +1706,9 @@ proc channel_mode {this vals} {
 		    set cdata(limit) $par
 		    $this showInfo limit "Limit: $par"
 		}
+	    b   {
+		    banProtect $this $prefix $flag $par
+	        }
 	    }
 	    handleOn $net MODE [list [$this name] $flag$m $par]
 	}
