@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1998/03/18 13:02:49 $
-# $Revision: 1.18.1.65 $
+# $Date: 1998/04/15 12:16:05 $
+# $Revision: 1.18.1.67 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -22,6 +22,7 @@ class Channel {
     join	0	{bool}
     nocase	0	{bool {Ignore Case}}
     nosort	0	{bool {Do not sort}}
+    noshow	0	{bool}
     open	0	{bool}
     close	0	{bool}
     draw	1	{bool}
@@ -183,6 +184,7 @@ class Friend {
     notify	1	{bool}
     menu	1	{bool}
     id		{}	{userhost}
+    protect	{}	{list}
 } {
     nick	{}
     lnick	{}
