@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1998/02/26 09:56:53 $
-# $Revision: 1.18.1.85 $
+# $Date: 1998/03/20 14:39:00 $
+# $Revision: 1.18.1.86 $
 #
 #
 package provide zircon 1.18
@@ -137,9 +137,10 @@ proc MainControl {} {
 	foreach x {0 1 2 3} {grid columnconfigure $hf $x -weight 1}
 	netspaceMenu $hf
 	set om [makeMB $hf.help Help]
+	set hc 0
 	foreach x [glob -nocomplain [file join $zircon(lib) help *]] {
 	    set x [file tail $x]
-	    set nm [string tolower $x]
+	    set nm m[incr hc]
 	    $om add cascade -label $x -menu $om.$nm
 	    menu $om.$nm -tearoff 0 -postcommand "makeHelp $om.$nm $x"
 	}
