@@ -1,7 +1,7 @@
-#
+ #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 1998/03/23 11:27:01 $
-# $Revision: 1.18.1.47 $
+# $Date: 1998/04/15 12:16:07 $
+# $Revision: 1.18.1.49 $
 #
 package provide zircon 1.18
 #
@@ -103,7 +103,7 @@ proc ircMODE {net prefix param pargs} {
 	}
 	return
     }
-    $id mode [set pd [lrange $pargs 1 end]]
+    $id mode [set pd [lrange $pargs 1 end]] $prefix
     $id optText MODE "*** Mode change \"[string trim \
       [join $pd]]\" on channel $chan by [lindex [mung1Prefix $net $prefix] 0]"
 }
@@ -150,13 +150,14 @@ proc ircPRIVMSG {net prefix param pargs} {
 		set where [Message :: make $net $nk]
 		if {[$where timestamp]} {set ts {}} {set ts "[getDate]\n"}
 		$where addText $usr "$ts$pfx $param"
+		doPatterns $where $prefix $param
 	    }
 	} default {
 	    $where show
 	    if {![$where isJoined $usr]} {$where addUser $usr 0 0}
 	    $where addText $usr "$pfx $param"
+	    doPatterns $where $prefix $param
 	}
-	doPatterns $where $prefix $param
 	handleOn $net MSG [list $prefix $param]
     } {
 	if {[ignoreSet $ign public]} return
@@ -306,7 +307,7 @@ proc ircKICK {net prefix param pargs} {
     } {
 	$id optText KICK \
 	  "*** $nk has been kicked off channel $chan by $kicker ($param)"
-	$id killUser $who
+	$id kickUser $who $prefix 0
    }
    handleOn $net KICK [list $chan $prefix $nk $param]
    ditchPrefix $nkinfo
@@ -338,7 +339,7 @@ proc ircKILL {net prefix param pargs} {
 		if {[$id isJoined $who]} {
 		    $id optText KILL \
 		      "*** $nk has been killed by [lindex $nkinfo 0] ($param)"
-		    $id killUser $who
+		    $id kickUser $who $prefix 1
 		}
 	    }
 	}
