@@ -1,16 +1,21 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Sound.tcl,v $
-# $Date: 1998/02/09 16:56:51 $
-# $Revision: 1.18.1.9 $
+# $Date: 1998/04/14 12:21:58 $
+# $Revision: 1.18.1.10 $
 #
 package provide zircon 1.18
 #
 proc handleSound {net usr fl} {
     global zircon
     switch {} [$net wavplayer] {} default {
-	set dirs [split [$net wavpath] :]
-	lappend dirs [file join $zircon(prefdir) sounds] \
-	  [file join $zircon(lib) sounds]
+	switch [file pathtype $fl] absolute {
+	    set dirs [file dirname $fl]
+	    set fl [file tail $fl]
+	} default {
+	    set dirs [split [$net wavpath] :]
+	    lappend dirs [file join $zircon(prefdir) sounds] \
+	      [file join $zircon(lib) sounds]
+	}
 	switch {} [file extension $fl] {append fl .wav}
 	foreach x $dirs {
 	    if {[file exists [file join $x $fl]]} {
@@ -29,7 +34,8 @@ proc handleSound {net usr fl} {
 #
 proc doSendSound {net nk fl} {
     switch {} $fl return
-    $net CTCP SOUND $nk "$fl <$fl>"
+    set tfl [file tail [file rootname $fl]]
+    $net CTCP SOUND $nk "$tfl <$tfl>"
     handleSound $net [$net nickname] $fl
 }
 #
@@ -44,6 +50,7 @@ proc addSoundMenu {net menu chid} {
 proc buildSMenu {net menu chid} {
     global zircon
     $menu delete 0 end
+    catch {destroy $menu.more}
     set ptn {*.[wW][aA][vV]}
     set wavs {}
     set dirs [split [$net wavpath] :]
@@ -59,7 +66,14 @@ proc buildSMenu {net menu chid} {
     }
     $menu add command -label {Other file} -command "sendSound $net {[$chid name]}"
     $menu add separator
+    set cnt 0
     foreach x [lsort $wavs] {
+        if {[incr cnt] > 20} {
+	    set cnt 1
+	    set m [menu $menu.more -tearoff 0]
+	    $menu add cascade -label [trans more] -menu $m
+	    set menu $m
+	}
 	$menu add command -label [file tail [file rootname $x]] \
 	  -command "doSendSound $net {[$chid name]} {$x}"
     }
