@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
-# $Date: 1998/03/20 14:39:10 $
-# $Revision: 1.18.1.11 $
+# $Date: 1998/04/20 11:42:19 $
+# $Revision: 1.18.1.12 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -21,7 +21,7 @@ proc configWin {net} {
     wm title $w "Configure Netspace [$net name]"
     frame $w.btn
     foreach x {revert apply save dismiss} {
-	button $w.btn.$x -text [trans $x] -command "conf$x $net"
+	button $w.btn.$x -text [trans $x] -command "conf$x $net $w.f.chld"
     }
     evenGrid $w.btn column 0 3
     grid $w.btn.revert $w.btn.apply $w.btn.save $w.btn.dismiss -sticky ew
@@ -36,8 +36,7 @@ proc configWin {net} {
     tabShow $net $lastConf($net)
 }
 #
-set Tabs {Nicknames IRCNames Servers Channels Messages Notices Chat DCC \
-      Friends Ignores Info}
+set Tabs {Nicknames IRCNames Servers Channels Friends Ignores Info}
 #
 proc drawTabs {net} {
     global lastConf Tabs
@@ -131,7 +130,7 @@ proc confrevclean {net which} {
     if {[listmember $Tabs $which]} { confUnchange $net $which }
 }
 #
-proc confdismiss {net} {
+proc confdismiss {net win} {
     catch {uplevel #0 unset new$net}
     switch {} [$net confChange] {} default {
 	if {![askUser SAVECONF {Save Changes} "You have unsaved changes. Really	dismiss?"]} return
@@ -142,14 +141,14 @@ proc confdismiss {net} {
     }
 }
 #
-proc confrevert {net} {
+proc confrevert {net win} {
     global lastConf
     confrevclean $net $lastConf($net)
-    conf$lastConf($net) $net
+    conf$lastConf($net) $net $win
     confClean $net
 }
 #
-proc confsave {net} {
+proc confsave {net win} {
     global lastConf
     confCopyBack $net $lastConf($net)
     saverc $net
@@ -157,7 +156,7 @@ proc confsave {net} {
     confClean $net
 }
 #
-proc confapply {net} {
+proc confapply {net win} {
     global lastConf
     confCopyBack $net $lastConf($net)
     confInit $net $lastConf($net)
