@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/dialog.tcl,v $
-# $Date: 1997/06/07 13:14:35 $
-# $Revision: 1.18.1.30 $
+# $Date: 1998/02/09 16:57:08 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -14,24 +14,24 @@ proc doButtons {w plv pars} {
 	grid $w.bot.0 -row 0 -column 0 -padx 5 -padx 5
 	switch {} [set cmd [lindex $arg 1]] {} default {append cmd " $param"}
 	switch {} $lv {} default {
-	   bind $lv <Return> "$cmd ; killWindow $w ; notIdle {} ; break"
-	   bind $lv <Tab> "focus $w.top.v1 ; notIdle {} ; break"
+	   bind $lv <Return> "$cmd ; killWindow $w ; break"
+	   bind $lv <Tab> "focus $w.top.v1 ; break"
 	}
 	button $w.bot.0.button -text [trans [lindex $arg 0]] -width 7 \
-		-command "$cmd ; killWindow $w ; notIdle {}"
+		-command "$cmd ; killWindow $w"
 	grid $w.bot.0.button -sticky ew -padx 5 -pady 5
-	bind $w <Return> "$cmd ; killWindow %W ; notIdle {} ; break"
+	bind $w <Return> "$cmd ; killWindow %W ; break"
 	set i 1
 	foreach arg [lrange $pars 1 end] {
 	    switch {} [set cmd [lindex $arg 1]] {} default {append cmd " $param"}
 	    switch -glob -- [set lbl [lindex $arg 0]] {
 	    -* {
 		    set lbl [trans [string index $lbl 1 end]]
-		    button $w.bot.$i -text $lbl -width 7 -command "$cmd ; notIdle {}"
+		    button $w.bot.$i -text $lbl -width 7 -command $cmd
 		}
 	    default {
 		    button $w.bot.$i -text [trans $lbl] -width 7 \
-		      -command "$cmd ; killWindow $w ; notIdle {}"
+		      -command "$cmd ; killWindow $w"
 		}
 	    }
 	    grid $w.bot.$i -row 0 -column $i -padx 5 -pady 5
@@ -39,7 +39,7 @@ proc doButtons {w plv pars} {
 	}
     }
     switch {} $lv {set sf $w} default {set sf $w.top.v1}
-    bind $w <Any-Enter> "focus $sf ; notIdle {} ; break"
+    bind $w <Any-Enter> "focus $sf ; break"
     focus $sf
 }
 #
@@ -74,8 +74,8 @@ proc doEntries {w entries} {
 	grid $lb -row $vb -column 0 -padx 5 -pady 5
 	grid $lv -row $vb -column 1 -sticky ew -padx 10 -pady 10
 	incr vb
-	bind $lv <Return> "notIdle {} ; focus $w.top.v$vb ; break "
-	bind $lv <Tab> "notIdle {} ; focus $w.top.v$vb ; break"
+	bind $lv <Return> "focus $w.top.v$vb ; break "
+	bind $lv <Tab> "focus $w.top.v$vb ; break"
     }
     return [list $lv $param]
 }
@@ -105,7 +105,7 @@ proc mkDialog {kind w title msgText entries args} {
     }
     switch {} $kind {} default {
 	upvar #0 currentNet net
-	if [listmember [$net noConfirm] $kind] {
+	if {[listmember [$net noConfirm] $kind]} {
 	    set param {}
 	    foreach entry $entries { append param "{[lindex $entry 1]}" }
 	    if {[llength $args] > 0 && \
@@ -115,30 +115,14 @@ proc mkDialog {kind w title msgText entries args} {
 	    eval $cmd
 	    return {}
 	}
-	if [listmember [$net toInfo] $kind] {
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
 	    $net inform $msgText
-	    return {}
+	    if {$ti} return {}
 	}
     }
-    set just [expr {[listmember \
-      {DCC WHO STATS INFO LINKS WHOIS} $kind] ? {left} : {center}}]
     switch {} $w {set w .@[newName dlg]} default {killWindow $w}
     dialogWindow $w $title
-    switch left $just {
-        frame $w.top.message
-        grid columnconfigure $w.top.message 0 -weight 1
-	scrollbar $w.top.message.vscroller -command "$w.top.message yview"
-	text $w.top.message.message -yscrollcommand "$w.top.vscroller set"
-	bindtags $w.top.message.message ROText
-	$w.top.message.message insert insert $msgText
-	set ln [lindex [split [$w.top.message.message index end] .] 0]
-	$w.top.message.message conf -height $ln
-	grid $w.top.message.message -row 0 -column 0 -sticky nsew
-	grid $w.top.message.vscroller -row 0 -column 1 -sticky ns
-
-    } default {
-	message $w.top.message -justify $just -text $msgText -aspect 800
-    }
+    message $w.top.message -justify center -text $msgText -aspect 800
     grid $w.top.message - -sticky nsew
     set lv [doEntries $w $entries]
     doButtons $w $lv $args
@@ -188,18 +172,16 @@ proc mkInfoBox {net kind w title msgText args} {
 	set args [list [list [trans dismiss] {}]]
     }
     switch {} $kind {} default {
-	if [listmember [$net noConfirm] $kind] {
+	if {[listmember [$net noConfirm] $kind]} {
 	    if {[llength $args] > 0} {eval [lindex [lindex $args 0] 1] }
 	    return [[$net info] text]
 	}
-	if [listmember [$net toInfo] $kind] {
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
 	    $net inform $msgText
-	    return [[$net info] text]
+	    if {$ti} { return [[$net info] text] }
 	}
     }
-    set just [expr {[listmember \
-      {DCC WHO STATS INFO LINKS WHOIS} $kind] ? {left} : {center}}]
-
+    set just [expr {[listmember {WHO INFO LINKS} $kind] ? {left} : {center}}]
     switch {} $w {set w .@[newName ifb]} default {killWindow $w}
     dialogWindow $w $title
     bind $w.top <Destroy> break
@@ -244,13 +226,13 @@ proc fillFile {w fn} {
     set od [pwd]
     cd $fn
     set ptns *
-    if $Shall($w) { set ptns {.* *} }
+    if {$Shall($w)} { set ptns {.* *} }
 	foreach ptn $ptns {
-	if ![catch {set fls [glob -nocomplain $ptn]}] {
+	if {![catch {set fls [glob -nocomplain $ptn]}]} {
 	    foreach fl [lsort $fls] {
 		switch -exact -- $fl { . - .. { continue} }
-		if [file isdirectory $fl] { append fl / } \
-		elseif ![regexp -- $FBFilter($w) $fl] { continue }
+		if {[file isdirectory $fl]} { append fl / } \
+		elseif {![regexp -- $FBFilter($w) $fl]} continue
 		$w.mid.flist.l insert end $fl
 	    }
 	}
@@ -260,7 +242,7 @@ proc fillFile {w fn} {
 #
 proc checkFile {w fn cmd init dirv} {
     upvar #0 $dirv dir
-    if [file isdirectory [set fn [file join $dir $fn]]] {
+    if {[file isdirectory [set fn [file join $dir $fn]]]} {
 	set dir $fn
 	regexp {^(.+)/$} $dir m dir
 	setDirMenu $w $cmd $init $dirv
@@ -269,7 +251,6 @@ proc checkFile {w fn cmd init dirv} {
     } {
 	eval $cmd $fn
 	killFWindow $w
-	notIdle {}
     }
 }
 #
@@ -327,21 +308,21 @@ proc mkFileBox {w dirv filter title msgText init args} {
 	set cmd [lindex $arg 1]
 	switch {} $cmd {} default {append cmd " \[file join \[set $dirv\] \[$w.mid.e4 get\]\]"}
 	button $w.bot.0.button -text [trans [lindex $arg 0]] \
-		-command "$cmd ; killFWindow $w ; notIdle {}"
+		-command "$cmd ; killFWindow $w"
 	grid $w.bot.0.button -padx 5 -pady 5
-	bind $w <Return> "$cmd ; killFWindow %W ; notIdle {} ; break"
+	bind $w <Return> "$cmd ; killFWindow %W ; break"
 	focus $w
 	set i 1
 	foreach arg [lrange $args 1 end] {
 	    set cmd [lindex $arg 1]
 	    switch {} $cmd {} default {append cmd " \[file join \[set $dirv\] \[$w.mid.e4 get\]\]"}
 	    button $w.bot.$i -text [trans [lindex $arg 0]] \
-	      -command "$cmd ; killFWindow $w ; notIdle {}"
+	      -command "$cmd ; killFWindow $w"
 	    grid $w.bot.$i -row 0 -column $i
 	    incr i
 	}
     }
-    bind $w <Any-Enter> {focus %W ; notIdle {} ; break}
+    bind $w <Any-Enter> {focus %W ; break}
     dialogPosn $w
     return $w
 }
@@ -386,16 +367,55 @@ proc warnUser {t m} {
 proc askUser {kind t m} {
     switch {} $kind {} default {
 	global currentNet
-	if [listmember [$currentNet noConfirm] $kind] { return 1 }
+	if {[listmember [$currentNet noConfirm] $kind]} { return 1 }
     }
     switch [tk_dialog .@[newName au] $t $m question 0 yes no] 0 {return 1} 1 {return 0}
+
 }
 #
-proc tellError {net t m} {
+switch -glob -- 8* [info tclversion] {
+proc tellError {net t m args} {
+    switch {} $args {set kind ERROR} default { set kind [lindex $args 0]}
     switch {} $net {} default {
-	if [listmember [$net toInfo] ERROR] {$net inform $m ; return}
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
+	    $net inform $m
+	    if {$ti} return
+	}
+    }
+    tk_messageBox -icon error -title $t -message $m -type ok
+}
+#
+proc tellInfo {net t m args} {
+    switch {} $args {} default {
+	set kind [lindex $args 0]
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
+	    $net inform $m
+	    if {$ti} return
+	}
+    }
+    tk_messageBox -icon info -title $t -message $m -type ok
+}
+} default {
+proc tellError {net t m args} {
+    switch {} $args { set kind ERROR } default { set kind [lindex $args 0]}
+    switch {} $net {} default {
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
+	    $net inform $m
+	    if {$ti} return
+	}
     }
     tk_dialog .@[newName te] $t $m error 0 [trans ok]
 }
 #
-proc tellInfo {t m} {tk_dialog .@[newName ti] $t $m info 0 [trans ok]}
+proc tellInfo {net t m args} {
+    switch {} $args {} default {
+	set kind [lindex $args 0]
+	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
+	    $net inform $m
+	    if {$ti} return
+	}
+    }
+    tk_dialog .@[newName ti] $t $m info 0 [trans ok]
+}
+}
+
