@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/errors.tcl,v $
-# $Date: 1998/02/10 10:48:41 $
-# $Revision: 1.18.1.17 $
+# $Date: 1998/04/14 12:22:01 $
+# $Revision: 1.18.1.18 $
 #
 package provide zircon 1.18
 #
@@ -85,7 +85,7 @@ proc cantUseNick {net prefix param pargs msg} {
 #
 proc irc442 {net prefix param pargs} {
     if {[[set ch [Channel :: find [set nm [lindex $pargs 1]] $net]] active]} {
-	$ch delete
+	$ch addText @ERROR "*** Error 442 : $nm $param [lindex $pargs 2]"
     } {
 	tellError $net {Channel Error} "$nm $param [lindex $pargs 2]"
     }
