@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1998/03/17 09:36:05 $
-# $Revision: 1.18.1.28 $
+# $Date: 1998/04/14 15:22:10 $
+# $Revision: 1.18.1.29 $
 #
 #
 package provide zircon 1.18
@@ -258,7 +258,47 @@ proc /NOTICE {net chid arg} {
     $net NOTICE [lindex $arg 0] [lrange $arg 1 end]
 }
 #
-proc /NOTIFY {net chid arg} { sillyPerson $net }
+proc /NOTIFY {net chid arg} { 
+    switch -- $arg {} {
+	set here {}
+	set nothere {}
+        foreach x [$net friends] {
+	    if [$x ison] {
+	    	lappend here $x
+	    } {
+	    	lappend nothere $x
+	    }   
+	}
+	set msg "Currently present:"
+	foreach x $here { append msg " [$x name]" }
+	append msg "\nCurrently absent:"
+	foreach x $nothere { append msg " [$x name]" }
+	mkDialog ISON {} [trans notify] $msg {} ok
+	return
+    } + {
+	set here {}
+        foreach x [$net friends] {
+	    if [$x ison] { lappend here $x } 
+	}
+	set msg "Currently present:"
+	foreach x $here { append msg " [$x name]" }
+	mkDialog ISON {} [trans notify] $msg {} ok
+        return
+    } - {
+    	foreach x [$net friends] { $x configure -notify 0 }
+        return
+    }
+    foreach x $arg {
+        regexp {(-?)(.*)} $x m off nick
+	set id [Friend :: make $net $nick]
+	$id configure -notify [expr {$off == {}}]
+	switch {} [$id usr] {
+	    switch nil [set usr [User :: find $nick $net]] {} default {
+	    	$id configure -usr $usr
+	    }
+	}
+    }
+}
 #
 proc /ON {net chid arg} { sillyPerson $net }
 #
