@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/03/11 10:52:08 $
-# $Revision: 1.18.1.48 $
+# $Date: 1998/03/25 13:46:33 $
+# $Revision: 1.18.1.51 $
 #
 package provide Dcc 1.18
 #
@@ -11,6 +11,11 @@ proc doDCC {net cmd nk} {
     [User :: make $net $nk] dcc $cmd
 }
 #
+proc deSpace {file} {
+    regsub -all { } $file {_} file
+    return $file
+}
+#
 proc dodRename {net file new} {
    switch {} $new return
    filerename $file $new
@@ -47,7 +52,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	          {Rename Existing} Cancel] { 
 	        0 {}
 	        1 {
-		      $net CTCP DCC [$usr name] "RESUME [file tail $file] $port $fp"
+		      $net CTCP DCC [$usr name] "RESUME [deSpace [file tail $file]] $port $fp"
 		      global Resume
 		      if {![info exists Resume($usr)]} {$usr ref}
 		      lappend Resume($usr) [list $file $addr $port $leng $fp]
@@ -320,7 +325,7 @@ proc buildDCCList {net args} {
 		grid [label $w1.f$ix -text [lindex $fl 1]] \
 		  -row $grd -column 1 -sticky w -padx 5
 		grid [button $w1.b$ix -text [trans cancel] \
-		  -command "dccClose $net $arr $nn [lindex $fl 1] $ix $w1"]\
+		  -command "dccClose $net $arr $nn [list [lindex $fl 1]] $ix $w1"]\
 		  -sticky ew -row $grd -column 2
 		incr grd
 	    }
