@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dccget.tcl,v $
-# $Date: 1998/03/17 09:36:08 $
-# $Revision: 1.18.1.6 $
+# $Date: 1998/03/25 13:46:34 $
+# $Revision: 1.18.1.7 $
 #
 package provide Dcc 1.18
 #
@@ -35,7 +35,7 @@ proc startGet {sk net file usr leng posn} {
 	if {$posn != 0} {
 	    if {[catch {seek $out $posn start} msg]} {
 	    	close $out
-	    	endDCC Get $who $sk $net "Cannot seek on $file: $msg"
+	    	endDCC Get $usr $sk $net "Cannot seek on $file : $msg"
 		return 0
 	    }
 	    incr leng -$posn
@@ -49,7 +49,7 @@ proc startGet {sk net file usr leng posn} {
 	if {[winfo exists .@dls$net]} { buildDCCList $net }
 	dccWindow $sk $usr Get $file
     } {
-        endDCC Get $who $in $net "Cannot write $file:$out"
+        endDCC Get $usr $in $net "Cannot write $file : $out"
         return 0
     }
     return 1
@@ -75,13 +75,17 @@ proc dccgevent {in out leng who net st} {
     } {
         if {![catch {set buffer [read $in]} msg]} {
             incr tl($in) [set l [string length $buffer]]
-            if {[set dt [expr {[clock seconds] - $st}]] == 0} {
+            if {[set dt [expr {[clock seconds] - $st}]] == 0 || $tl($in) == 0} {
                 set elt 0
             } {
-                set elt [expr {($leng - $tl($in)) / ($tl($in) /([clock seconds] - $st))}]
-            }
-            dccProgress $in $tl($in) [expr {($tl($in) *100.0) / $leng}] \
-              [expr {$elt / 60}] [expr {$elt % 60}]
+	        set elt [expr {($leng - $tl($in)) / ($tl($in) /([clock seconds] - $st))}]
+	    }
+	    if {$leng == 0} {
+	    	set xt 0
+	    } {
+	        set xt [expr {($tl($in) * 100.0) / $leng}]
+	    }
+            dccProgress $in $tl($in) $xt [expr {$elt / 60}] [expr {$elt % 60}]
             if {![catch {puts -nonewline $out $buffer} msg]} {
 	        if {![catch {puts -nonewline $in [binary format I1 $tl($in)]} msg]} {
 	            return
