@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/send.tcl,v $
-# $Date: 1998/02/26 15:51:32 $
-# $Revision: 1.18.1.23 $
+# $Date: 1998/03/25 13:46:36 $
+# $Revision: 1.18.1.26 $
 #
 package provide Dcc 1.18
 #
@@ -13,25 +13,26 @@ proc DCCSend {usr file} {
 	    return
 	}
 	set net [$usr net]
-	set file [glob $file]
 	set xfile [file tail $file]
-	global zircon
+	set file [file join [file dirname $file] $xfile]
 	upvar #0 Offer$net Offer
 	set ky [newName Scon]
-	set sock [socket -server "acceptSend $net $ky $file $usr" 0]
+	set sock [socket -server "acceptSend $net $ky [list $file] $usr" 0]
 	if {[catch {fconfigure $sock -sockname} xx]} {
 	    error "Cannot get port for server - $xx"
 	}
 	if {![info exists Offer($usr)]} { $usr ref }
 	lappend Offer($usr) [list $ky $file $sock [lindex $xx 2] 0 0]
 	$net CTCP DCC [$usr name] \
-	  "SEND $xfile [ipPack [ipAddress]] [lindex $xx 2] [file size $file]"
+	  "SEND [deSpace $xfile] [ipPack [ipAddress]] [lindex $xx 2] [file size $file]"
 	if {[winfo exists .@dls$net]} { buildDCCList $net }
     } {
 	tellError {} {File error} "File \"$file\" does not exist."
     }
 }
 #
+switch -glob -- [info tclversion] 7.* {
+#
 proc handleInfo {net conn} {
     if {[catch {gets $conn} msg] || ([string match {} $msg] && [eof $conn])} {
 	catch {close $conn}
@@ -58,6 +59,8 @@ proc handleInfo {net conn} {
     }
 }
 #
+}
+#
 proc endDCC {type who conn net msg args} {
     upvar #0 $type$net gsnet
     set x [lsearch $gsnet($who) "$conn *"]
@@ -83,6 +86,7 @@ proc endDCC {type who conn net msg args} {
 	    if {[lindex $args 0]} { $net fileProcess $file $who }
 	}
     }
+    if {[winfo exists .@dls$net]} { buildDCCList $net }
 }
 #
 proc dccAutoDir {net fln} {
@@ -94,9 +98,7 @@ proc dccAutoDir {net fln} {
     return {}
 }
 #
-switch -glob [info tclversion] {
-8* -
-{7.6} {
+switch -glob [info tclversion] 8* - {7.6} {
 #
 proc handleSend {net fln usr addr port leng posn auto} {
     global GetDir zFileTypes
@@ -122,8 +124,9 @@ proc handleSend {net fln usr addr port leng posn auto} {
 	doGetDCC $net Get $usr $addr $port $leng $posn $fl
     }
 }
-}
-default {
+#
+} default {
+#
 proc handleSend {net fln usr addr port leng posn auto} {
     if {$auto} {
 	switch {} [set fl [dccAutoDir $net $fln]] {} default {
@@ -143,7 +146,7 @@ proc handleSend {net fln usr addr port leng posn auto} {
       [list accept "doGetDCC $net Get $usr $addr $port $leng $posn"] \
       [list reject {}]]
 }
-}
+#
 }
 #
 proc handleResume {net usr file port posn} {
@@ -157,7 +160,7 @@ proc handleResume {net usr file port posn} {
 	    switch -- $port [lindex $l 3] {
 		set Offer($usr) [lreplace $Offer($usr)\
 		  $i $i [lreplace $l 4 4 $posn]]
-		$net CTCP DCC [$usr name] "ACCEPT $file $port $posn"
+		$net CTCP DCC [$usr name] "ACCEPT [deSpace $file] $port $posn"
 		set fnd 1
 		break
 	    }
